import * as ec2 from 'aws-cdk-lib/aws-ec2';
import * as assets from 'aws-cdk-lib/aws-ecr-assets';
import * as ecs from 'aws-cdk-lib/aws-ecs';
import { InfrastructureDefinition } from './infrastructure';
/**
 * @param instanceType the instance type to evaluate.
 * @returns whether the instance type is a GPU instance.
 */
export declare const isGpu: (instanceType: ec2.InstanceType) => boolean;
/**
 * @param infrastructure the infrastructure to use.
 * @returns the GPU configuration for the given infrastructure.
 */
export declare const getGpuConfiguration: (infrastructure: InfrastructureDefinition) => {
    instanceType: ec2.InstanceType;
    memoryLimitMiB: number;
    gpuCount: number;
    container: {
        platform: assets.Platform;
    };
    machineImage: ecs.EcsOptimizedImage;
};
/**
 * @returns the CPU configuration for the given infrastructure.
 * @param infrastructure the infrastructure to use.
 */
export declare const getCpuConfiguration: (infrastructure: InfrastructureDefinition) => {
    instanceType: ec2.InstanceType;
    memoryLimitMiB: number;
    gpuCount: number;
    container: {
        platform: assets.Platform;
    };
    machineImage: ecs.EcsOptimizedImage;
};
/**
 * @returns the configuration to use for the given infrastructure and compute type.
 * @param infrastructure the infrastructure to use.
 * @param computeType the compute type to use.
 */
export declare const getConfiguration: (infrastructure: InfrastructureDefinition) => {
    instanceType: ec2.InstanceType;
    memoryLimitMiB: number;
    gpuCount: number;
    container: {
        platform: assets.Platform;
    };
    machineImage: ecs.EcsOptimizedImage;
};
