export interface OllamaEmbeddingModelDefinition {
    /**
     * The tag of the model.
     */
    tag: string;
    /**
     * The input mime-types supported by the model.
     */
    inputs: string[];
    /**
     * The output mime-types supported by the model.
     */
    outputs: string[];
}
/**
 * An array of base input mime-types
 * supported by ollama text models.
 */
export declare const BASE_TEXT_INPUTS: string[];
/**
 * A helper to select an embedding model supported
 * by Ollama.
 */
export declare class OllamaEmbeddingModel {
    name: string;
    definition: OllamaEmbeddingModelDefinition;
    /**
     * The `nomic-embed-text` model.
     * @see https://ollama.com/library/nomic-embed-text
     */
    static readonly NOMIC_EMBED_TEXT: OllamaEmbeddingModel;
    /**
     * The `mxbai-embed-large` model.
     * @see https://ollama.com/library/mxbai-embed-large
     */
    static readonly MXBAI_EMBED_LARGE: OllamaEmbeddingModel;
    /**
     * The `all-minilm` model.
     * @see https://ollama.com/library/all-minilm
     */
    static readonly ALL_MINILM: OllamaEmbeddingModel;
    /**
     * The `snowflake-arctic-embed` model.
     * @see https://ollama.com/library/snowflake-arctic-embed
     */
    static readonly SNOWFLAKE_ARCTIC_EMBED: OllamaEmbeddingModel;
    /**
     * The `bge-m3` model.
     * @see https://ollama.com/library/bge-m3
     */
    static readonly BGE_M3: OllamaEmbeddingModel;
    /**
     * The `bge-large` model.
     * @see https://ollama.com/library/bge-large
     */
    static readonly BGE_LARGE: OllamaEmbeddingModel;
    /**
     * The `paraphrase-multilingual` model.
     * @see https://ollama.com/library/paraphrase-multilingual
     */
    static readonly PARAPHRASE_MULTILINGUAL: OllamaEmbeddingModel;
    /**
     * Create a new instance of the `OllamaEmbeddingModel`
     * by name.
     * @param name the name of the model.
     * @returns a new instance of the `OllamaEmbeddingModel`.
     */
    static of(name: string, opts: {
        tag: string;
    }): OllamaEmbeddingModel;
    /**
     * Creates a new instance of the `OllamaEmbeddingModel` class.
     * @param name the name of the model.
     * @param definition the model definition.
     */
    constructor(name: string, definition: OllamaEmbeddingModelDefinition);
    /**
     * Sets the tag of the model.
     * @param tag the tag of the model.
     * @returns the model instance.
     */
    tag(tag: string): this;
}
