import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { z } from 'zod';
import { OllamaEmbeddingModel } from './model';
import { InfrastructureDefinition } from './infrastructure';
/**
 * The middleware properties.
 */
export declare const OllamaEmbeddingProcessorPropsSchema: z.ZodObject<z.objectUtil.extendShape<{
    sources: z.ZodType<Set<import("@project-lakechain/core/middleware").Middleware>, z.ZodTypeDef, Set<import("@project-lakechain/core/middleware").Middleware>>;
    destinations: z.ZodType<Set<import("@project-lakechain/core/middleware").Middleware>, z.ZodTypeDef, Set<import("@project-lakechain/core/middleware").Middleware>>;
    conditionals: z.ZodMap<z.ZodString, z.ZodType<import("@project-lakechain/core/dsl/vocabulary/conditions").ConditionalStatement, z.ZodTypeDef, import("@project-lakechain/core/dsl/vocabulary/conditions").ConditionalStatement>>;
    computeType: z.ZodOptional<z.ZodDefault<z.ZodNativeEnum<typeof import("@project-lakechain/core/compute-type").ComputeType>>>;
    maxRetry: z.ZodOptional<z.ZodDefault<z.ZodNumber>>;
    queueVisibilityTimeout: z.ZodOptional<z.ZodDefault<z.ZodType<import("aws-cdk-lib").Duration, z.ZodTypeDef, import("aws-cdk-lib").Duration>>>;
    batchingWindow: z.ZodOptional<z.ZodEffects<z.ZodType<import("aws-cdk-lib").Duration, z.ZodTypeDef, import("aws-cdk-lib").Duration>, import("aws-cdk-lib").Duration, import("aws-cdk-lib").Duration>>;
    batchSize: z.ZodOptional<z.ZodNumber>;
    maxConcurrency: z.ZodOptional<z.ZodNumber>;
    cloudWatchInsights: z.ZodDefault<z.ZodBoolean>;
    cacheStorage: z.ZodType<import("@project-lakechain/core/cache-storage").CacheStorage, z.ZodTypeDef, import("@project-lakechain/core/cache-storage").CacheStorage>;
    logRetention: z.ZodDefault<z.ZodType<import("aws-cdk-lib/aws-logs").RetentionDays, z.ZodTypeDef, import("aws-cdk-lib/aws-logs").RetentionDays>>;
    maxMemorySize: z.ZodOptional<z.ZodNumber>;
    kmsKey: z.ZodOptional<z.ZodType<import("aws-cdk-lib/aws-kms").IKey, z.ZodTypeDef, import("aws-cdk-lib/aws-kms").IKey>>;
    keyReusePeriod: z.ZodDefault<z.ZodType<import("aws-cdk-lib").Duration, z.ZodTypeDef, import("aws-cdk-lib").Duration>>;
    vpc: z.ZodOptional<z.ZodType<ec2.IVpc, z.ZodTypeDef, ec2.IVpc>>;
}, {
    /**
     * The VPC used by the middleware.
     */
    vpc: z.ZodType<ec2.IVpc, z.ZodTypeDef, ec2.IVpc>;
    /**
     * The identifier of the ollama model to use.
     */
    model: z.ZodType<OllamaEmbeddingModel, z.ZodTypeDef, OllamaEmbeddingModel>;
    /**
     * The infrastructure to run the ollama model.
     */
    infrastructure: z.ZodType<InfrastructureDefinition, z.ZodTypeDef, InfrastructureDefinition>;
    /**
     * The maximum amount of documents to process in a
     * single batch.
     * @min 1
     * @max 10
     * @default 1
     */
    batchSize: z.ZodDefault<z.ZodNumber>;
    /**
     * The maximum amount of containers to run concurrently
     * to process the documents.
     * @min 1
     * @default 5
     */
    maxConcurrency: z.ZodDefault<z.ZodNumber>;
}>, "strip", z.ZodTypeAny, {
    vpc: ec2.IVpc;
    logRetention: import("aws-cdk-lib/aws-logs").RetentionDays;
    model: OllamaEmbeddingModel;
    sources: Set<import("@project-lakechain/core/middleware").Middleware>;
    destinations: Set<import("@project-lakechain/core/middleware").Middleware>;
    conditionals: Map<string, import("@project-lakechain/core/dsl/vocabulary/conditions").ConditionalStatement>;
    batchSize: number;
    maxConcurrency: number;
    cloudWatchInsights: boolean;
    cacheStorage: import("@project-lakechain/core/cache-storage").CacheStorage;
    keyReusePeriod: import("aws-cdk-lib").Duration;
    infrastructure: InfrastructureDefinition;
    kmsKey?: import("aws-cdk-lib/aws-kms").IKey | undefined;
    computeType?: import("@project-lakechain/core/compute-type").ComputeType | undefined;
    maxRetry?: number | undefined;
    queueVisibilityTimeout?: import("aws-cdk-lib").Duration | undefined;
    batchingWindow?: import("aws-cdk-lib").Duration | undefined;
    maxMemorySize?: number | undefined;
}, {
    vpc: ec2.IVpc;
    model: OllamaEmbeddingModel;
    sources: Set<import("@project-lakechain/core/middleware").Middleware>;
    destinations: Set<import("@project-lakechain/core/middleware").Middleware>;
    conditionals: Map<string, import("@project-lakechain/core/dsl/vocabulary/conditions").ConditionalStatement>;
    cacheStorage: import("@project-lakechain/core/cache-storage").CacheStorage;
    infrastructure: InfrastructureDefinition;
    kmsKey?: import("aws-cdk-lib/aws-kms").IKey | undefined;
    logRetention?: import("aws-cdk-lib/aws-logs").RetentionDays | undefined;
    computeType?: import("@project-lakechain/core/compute-type").ComputeType | undefined;
    maxRetry?: number | undefined;
    queueVisibilityTimeout?: import("aws-cdk-lib").Duration | undefined;
    batchingWindow?: import("aws-cdk-lib").Duration | undefined;
    batchSize?: number | undefined;
    maxConcurrency?: number | undefined;
    cloudWatchInsights?: boolean | undefined;
    maxMemorySize?: number | undefined;
    keyReusePeriod?: import("aws-cdk-lib").Duration | undefined;
}>;
export type OllamaEmbeddingProcessorProps = z.infer<typeof OllamaEmbeddingProcessorPropsSchema>;
